PRO add_sources_interp, map, x, y, psf, f
  ;psf must be 2*N+1 pixels sources must be in the center of central pixel
  
;+
;  NAME: 
;     ADD_SOURCES_INTERP
;
;  PURPOSE:
;    Add sources on a map.
;
;  EXPLANATION:
;
;  CALLING SEQUENCE: 
;   add_sources_interp, map, x, y, psf, f
;
;  INPUTS: 
;     MAP   : Map to modify    
;     X : array of X position of sources (float)
;     Y : "        Y       "
;     PSF   : PSF of a unit flux source (Must be 2*N+1 pixels and
;     sources must be in the center of central pixel)
;     F : Array of flux of sources. (-fsources if you want to clean a map)
;
;
;  MODIFICATION HISTORY:
;  Write by Matthieu Bethermin (May 2009)


  psf_hs = ((size(psf))(1)-1)/2

  map_size = size(map)

  newmap = fltarr(map_size(1)+2*psf_hs+5,map_size(2)+2*psf_hs+5)
  newmap[psf_hs+1:map_size(1)+psf_hs,psf_hs+1:map_size(2)+psf_hs] = map

  for j = 0L, n_elements(x)-1 do begin 
     delta_x = x(j) - round(x(j))
     delta_y = y(j) - round(y(j))
     IF delta_x ge 0.5 THEN delta_x = delta_x - 1
     IF delta_y ge 0.5 THEN delta_y = delta_y - 1
     xinterp    = FINDGEN(2*psf_hs+1) - delta_x
     yinterp    = FINDGEN(2*psf_hs+1) - delta_y
     psf_int    = INTERPOLATE(psf, xinterp, yinterp, /GRID)  
     xint = round(x(j))
     yint = round(y(j))
     newmap[xint+1:xint+2*psf_hs+1,yint+1:yint+2*psf_hs+1] = $
        newmap[xint+1:xint+2*psf_hs+1,yint+1:yint+2*psf_hs+1] $
        + psf_int*f(j)
  endfor

  newmap = newmap[psf_hs+1.:map_size(1)+psf_hs,psf_hs+1.:map_size(2)+psf_hs]

  map = newmap
  
END
